==> qtjambi-qt3drender-6.3.1-sources.jar: io/qt/qt3d/render/QStencilTest.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies arguments for the stecil test</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html">Qt3DRender::QStencilTest</a></p>
 */
public class QStencilTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilTest.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#QStencilTest">Qt3DRender::QStencilTest::QStencilTest(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilTest(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#back-prop">Qt3DRender::QStencilTest::back()const</a></p>
     */
    @io.qt.QtPropertyReader(name="back")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments back(){
        return back_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilTestArguments back_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#front-prop">Qt3DRender::QStencilTest::front()const</a></p>
     */
    @io.qt.QtPropertyReader(name="front")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments front(){
        return front_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilTestArguments front_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStencilTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QStencilTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QStencilTest instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3drender-6.4.3-sources.jar: io/qt/qt3d/render/QStencilTest.java <==
package io.qt.qt3d.render;


/**
 * <p>Specifies arguments for the stecil test</p>
 * <p>Java wrapper for Qt's class <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html">Qt3DRender::QStencilTest</a></p>
 */
public class QStencilTest extends io.qt.qt3d.render.QRenderState
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QStencilTest.class);
    
    
    /**
     * <p>Overloaded constructor for {@link #QStencilTest(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QStencilTest() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#QStencilTest">Qt3DRender::QStencilTest::QStencilTest(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    public QStencilTest(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QStencilTest instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#back-prop">Qt3DRender::QStencilTest::back()const</a></p>
     */
    @io.qt.QtPropertyReader(name="back")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments back(){
        return back_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilTestArguments back_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3drender-qstenciltest.html#front-prop">Qt3DRender::QStencilTest::front()const</a></p>
     */
    @io.qt.QtPropertyReader(name="front")
    @io.qt.QtPropertyConstant
    @io.qt.QtUninvokable
    public final io.qt.qt3d.render.QStencilTestArguments front(){
        return front_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.render.QStencilTestArguments front_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QStencilTest(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QStencilTest(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QStencilTest instance, QDeclarativeConstructor constructor);
    
}
